@@ -39,23 +39,6 @@ enum CheckableType
 	CheckableService
 };
 
-/**
- * Severity Flags
- *
- * @ingroup icinga
- */
-enum SeverityFlag
-{
-	SeverityFlagDowntime = 1,
-	SeverityFlagAcknowledgement = 2,
-	SeverityFlagHostDown = 4,
-	SeverityFlagUnhandled = 8,
-	SeverityFlagPending = 16,
-	SeverityFlagWarning = 32,
-	SeverityFlagUnknown = 64,
-	SeverityFlagCritical = 128,
-};
-
 class CheckCommand;
 class EventCommand;
 class Dependency;
@@ -85,12 +68,13 @@ public:
 
 	AcknowledgementType GetAcknowledgement();
 
-	void AcknowledgeProblem(const String& author, const String& comment, AcknowledgementType type, bool notify = true, bool persistent = false, double expiry = 0, const MessageOrigin::Ptr& origin = nullptr);
-	void ClearAcknowledgement(const MessageOrigin::Ptr& origin = nullptr);
+	void AcknowledgeProblem(const String& author, const String& comment, AcknowledgementType type, bool notify = true, bool persistent = false, double changeTime = Utility::GetTime(), double expiry = 0, const MessageOrigin::Ptr& origin = nullptr);
+	void ClearAcknowledgement(const String& removedBy, double changeTime = Utility::GetTime(), const MessageOrigin::Ptr& origin = nullptr);
 
 	int GetSeverity() const override;
 	bool GetProblem() const override;
 	bool GetHandled() const override;
+	Timestamp GetNextUpdate() const override;
 
 	/* Checks */
 	intrusive_ptr<CheckCommand> GetCheckCommand() const;
@@ -128,8 +112,9 @@ public:
 		const NotificationType&, const CheckResult::Ptr&, const String&,
 		const String&, const MessageOrigin::Ptr&)> OnNotificationSentToAllUsers;
 	static boost::signals2::signal<void (const Checkable::Ptr&, const String&, const String&, AcknowledgementType,
-		bool, bool, double, const MessageOrigin::Ptr&)> OnAcknowledgementSet;
-	static boost::signals2::signal<void (const Checkable::Ptr&, const MessageOrigin::Ptr&)> OnAcknowledgementCleared;
+		bool, bool, double, double, const MessageOrigin::Ptr&)> OnAcknowledgementSet;
+	static boost::signals2::signal<void (const Checkable::Ptr&, const String&, double, const MessageOrigin::Ptr&)> OnAcknowledgementCleared;
+	static boost::signals2::signal<void (const Checkable::Ptr&, double)> OnFlappingChange;
 	static boost::signals2::signal<void (const Checkable::Ptr&)> OnNextCheckUpdated;
 	static boost::signals2::signal<void (const Checkable::Ptr&)> OnEventCommandExecuted;
 
@@ -149,7 +134,7 @@ public:
 
 	/* Comments */
 	void RemoveAllComments();
-	void RemoveCommentsByType(int type);
+	void RemoveCommentsByType(int type, const String& removedBy = String());
 
 	std::set<Comment::Ptr> GetComments() const;
 	void RegisterComment(const Comment::Ptr& comment);
@@ -186,6 +171,9 @@ public:
 	void ValidateRetryInterval(const Lazy<double>& lvalue, const ValidationUtils& value) final;
 	void ValidateMaxCheckAttempts(const Lazy<int>& lvalue, const ValidationUtils& value) final;
 
+	bool NotificationReasonApplies(NotificationType type);
+	bool IsLikelyToBeCheckedSoon();
+
 	static void IncreasePendingChecks();
 	static void DecreasePendingChecks();
 	static int GetPendingChecks();
